@@ -102,12 +102,11 @@ class ElephasEstimator(Estimator, HasCategoricalLabels, HasValidationSplit, HasK
                         validation_split=self.get_validation_split())
 
         model_weights = spark_model.master_network.get_weights()
-        weights = simple_rdd.ctx.broadcast(model_weights)
         return ElephasTransformer(labelCol=self.getLabelCol(),
                                   outputCol=self.getOutputCol(),
                                   featuresCol=self.getFeaturesCol(),
                                   keras_model_config=spark_model.master_network.to_yaml(),
-                                  weights=weights,
+                                  weights=model_weights,
                                   custom_objects=self.get_custom_objects(),
                                   predict_classes=self.get_predict_classes(),
                                   model_type=LossModelTypeMapper().get_model_type(loss))
@@ -167,8 +166,9 @@ class ElephasTransformer(Model, HasKerasModelConfig, HasLabelCol, HasOutputCol,
     def get_config(self):
         return {'keras_model_config': self.get_keras_model_config(),
                 'labelCol': self.getLabelCol(),
+                'featuresCol': self.getFeaturesCol(),
                 'outputCol': self.getOutputCol(),
-                'weights': [weight.numpy().tolist() for weight in getattr(self, 'weights', [])],
+                'weights': [weight.tolist() for weight in getattr(self, 'weights', [])],
                 'model_type': getattr(self, 'model_type', None)}
 
     def save(self, file_name: str):
@@ -191,7 +191,7 @@ class ElephasTransformer(Model, HasKerasModelConfig, HasLabelCol, HasOutputCol,
         output_col = self.getOutputCol()
         new_schema = copy.deepcopy(df.schema)
         rdd = df.rdd
-        weights = self.weights
+        weights = rdd.ctx.broadcast(self.weights)
 
         def extract_features_and_predict(model_yaml: str,
                                          custom_objects: dict,
@@ -231,4 +231,5 @@ def load_ml_transformer(file_name: str):
     f = h5py.File(file_name, mode='r')
     elephas_conf = json.loads(f.attrs.get('distributed_config'), object_hook=as_enum)
     config = elephas_conf.get('config')
+    config['weights'] = [np.array(weight) for weight in config['weights']]
     return ElephasTransformer(**config)
